;; Generated package description from nameless.el  -*- no-byte-compile: t -*-
(define-package "nameless" "1.0.2.0.20190429.120252" "Hide package namespace in your emacs-lisp code" '((emacs "24.4")) :keywords '("convenience" "lisp") :authors '(("Artur Malabarba" . "emacs@endlessparentheses.com")) :maintainer '("Artur Malabarba" . "emacs@endlessparentheses.com") :url "https://github.com/Malabarba/nameless")
